@@ -12,6 +12,12 @@ import time
 from collections import Counter
 
 
+def chunks(lst, n):
+    """Yield successive n-sized chunks from lst."""
+    for i in range(0, len(lst), n):
+        yield lst[i:i + n]
+
+
 class GenerateCitationNet():
     """
     Generats a network of publications by citations or references using Crossref.
@@ -211,16 +217,19 @@ class GenerateCitationNet():
             return pd.DataFrame(), (time.time() - start_time)
         flDict.update({'rows': 100000})
         try:
-            searchStr = ' OR '.join(
-                [f'DOI: "{doi}"' for doi in data['reference.DOI']]
-                )
+            searchParts = []
+            for part in chunks(data['reference.DOI'], 999):
+                searchParts.append(
+                    ' OR '.join([f'DOI: "{doi}"' for doi in part])
+                    )
         except KeyError:
             return pd.DataFrame(), (time.time() - start_time)
-        tmpSearch = self.solr.search(searchStr, **flDict)
-        tmpResIN = [x for x in tmpSearch]
         tmpRes = []
-        for elem in tmpResIN:
-            tmpRes.append(self.getNodeData(elem, direction='target'))
+        for searchStr in searchParts:
+            tmpSearch = self.solr.search(searchStr, **flDict)
+            tmpResIN = [x for x in tmpSearch]
+            for elem in tmpResIN:
+                tmpRes.append(self.getNodeData(elem, direction='target'))
         ref_count = int(data['reference-count'][0])
         doi_count = len(data['reference.DOI'])
         if ref_count == doi_count:
@@ -450,7 +459,8 @@ class GenerateCitationNet():
                     if debug:
                         print(f'Found columns missing: {missingCols}, adding empty.')
                     for newcol in missingCols:
-                        dfRef.insert(0, newcol, '')
+                        dfRes.insert(0, newcol, '')
+                dfRes = dfRes.fillna('')
             else:
                 return
         self.resultDF = dfRes
